# -*- coding: utf-8 -*-
#   Copyright 2017 ProjectQ-Framework (www.projectq.ch)
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.

"""Definition of the QFT gate."""

from ._basics import BasicGate


class QFTGate(BasicGate):
    """Quantum Fourier Transform gate."""

    def __str__(self):
        """Return a string representation of the object."""
        return "QFT"


#: Shortcut (instance of) :class:`projectq.ops.QFTGate`
QFT = QFTGate()
